@@ -321,12 +321,11 @@ class CloneMixin(object):
         new_instance = cls()
 
         for f in fields:
-            value = f.get_default() or getattr(instance, f.attname, None)
+            if not f.editable:
+                f.pre_save(new_instance, add=True)
+                continue
 
-            if isinstance(f, (models.DateTimeField, models.DateField)):
-                if f.auto_now or f.auto_now_add:
-                    f.pre_save(new_instance, add=True)
-                    continue
+            value = getattr(instance, f.attname)
 
             if all(
                 [
@@ -354,7 +353,7 @@ class CloneMixin(object):
                         )
 
                 elif isinstance(f, models.OneToOneField) and not sub_clone:
-                    sub_instance = getattr(instance, f.name, f.get_default())
+                    sub_instance = getattr(instance, f.name, None) or f.get_default()
 
                     if sub_instance is not None:
                         sub_instance = CloneMixin._create_copy_of_instance(
